==> cmsform-gcp-8.0.000.1.tar.gz: cmsform/scripts/es.sh <==
#!/bin/bash
CS1_IP=$1
TIMETAG=$2
HOSTVAR=$3
HOSTDOMAIN=$4

#INSTANCENAME=$(curl -H "Metadata-Flavor: Google" http://metadata.google.internal/computeMetadata/v1/instance/name)
#INSTANCEZONE=$(curl -H "Metadata-Flavor: Google" http://metadata.google.internal/computeMetadata/v1/instance/zone)

## mkdir -p /opt/vmTools
## mkdir -p /opt/vmTools
##  # setup for using nfs client
## systemctl enable rpcbind.service
## systemctl start rpcbind
## "echo 'PEERDNS=no' | sudo tee -a /etc/sysconfig/network-scripts/ifcfg-eth0"
## # set the hostname
## hostname $HOSTNAME
## sed -i "/HOSTNAME=localhost.localdomain/c\\HOSTNAME=$HOSTNAME" /etc/sysconfig/network
## #turn off SELinux
## setenforce 0
## sed -i --follow-symlinks 's/^SELINUX=.*/SELINUX=disabled/g' /etc/sysconfig/selinux
##  #remove packages which will conflict with CMS packages
## sudo yum erase -y python-setuptools
## #iptables blocks access to httpd
## sudo systemctl stop firewalld

sudo chmod +x /opt/vmTools/*.sh
sudo bash /opt/vmTools/mountVMdisk.sh /var/log "0% 25%" /opt "26% 100%"
#sudo bash /opt/vmTools/setHostname.sh ${var.cms_hostname_es}${count.index + 1}
#sudo bash /opt/vmTools/setHostname.sh ${HOSTVAR}${TIMETAG}
sudo hostnamectl set-hostname ${HOSTVAR}${TIMETAG}
echo 'PEERDNS=no' | sudo tee -a /etc/sysconfig/network-scripts/ifcfg-eth0
sudo setenforce 0
sudo sed -i --follow-symlinks 's/^SELINUX=.*/SELINUX=disabled/g' /etc/sysconfig/selinux
sudo yum erase -y python-setuptools
sudo systemctl stop firewalld
sudo bash /opt/vmTools/waitAndPullNodeInstall.sh http://$CS1_IP:8008/cms-node-config.tgz
cd /opt/cms/staging

T_RANDOM=$(shuf -i 0-5 -n 1)
T1=$((${T_RANDOM} * 20))
T2=$((${TIMETAG} *20 % 100))
SLEEPTIME=$(($T1 + $T2))
echo "Sleeping with $SLEEPTIME" | sudo tee -a /home/test/gcpstartup.test.log;
#echo "Sleeping with $SLEEPTIME" | sudo tee -a /var/log/cms/installer/installcmsnode.log;

sleep $SLEEPTIME
# Do not specify the cname, the scripts cmsnsupdate.sh will set the cname automatically, limited within 10
sudo bash installcmsnode.sh es -t 600 |& sudo tee -a /var/log/cms/installer/installcmsnode.log; test $${PIPESTATUS[0]} -eq 0
## Reset the hostname to align with the cname
COUNT=$(cat /etc/facter/facts.d/node.yaml | grep 'cname: es' | grep -o [0-9]*)
sudo hostnamectl set-hostname $HOSTVAR$COUNT
sudo /bin/bash /etc/puppetlabs/code/modules/named/files/cmsnsupdate.sh
### Also need to update the hostname into GCP internal metadata server
#SCTOKEN=$(curl -H "Metadata-Flavor: Google" "http://metadata.google.internal/computeMetadata/v1/instance/service-accounts/default/token"|jq .access_token)
#curl https://compute.googleapis.com/compute/v1/$INSTANCEZONE/instances/$INSTANCENAME -H "Authorization":"Bearer $SCTOKEN" |jq .metadata > /home/instance_meta.json
#sed -i '/"items":/a{ "key": "hostname", "value": "'${HOSTVAR}${COUNT}'.'${HOSTDOMAIN}'" },' /home/instance_meta.json
#curl -X POST https://compute.googleapis.com/compute/v1/$INSTANCEZONE/instances/$INSTANCENAME/setMetadata -H "Authorization":"Bearer $SCTOKEN" -H "Content-Type: application/json" -d @/home/instance_meta.json
#
### Create label 
#LABELFP=$(curl https://compute.googleapis.com/compute/v1/$INSTANCEZONE/instances/$INSTANCENAME -H "Authorization":"Bearer $SCTOKEN" |jq .labelFingerprint)
#curl -X POST https://compute.googleapis.com/compute/v1/$INSTANCEZONE/instances/$INSTANCENAME/setLabels -H "Authorization":"Bearer $SCTOKEN" -H "Content-Type: application/json" -d '{ "labels": { "node": "'${HOSTVAR}${COUNT}'" }, "labelFingerprint": '${LABELFP}' }'
sudo bash /opt/vmTools/scripts/update_instance_metadata.sh $HOSTVAR$COUNT $HOSTDOMAIN

# Config the systemd-logind to make sure the customized shutdown scripts could be run before VM deleted
sudo sed -i '/PATH=/a sudo sh \/opt\/vmTools\/scripts\/deregister_node.sh' /etc/acpi/actions/power.sh
sudo sed -i '/HandlePowerKey/c HandlePowerKey=ignore' /etc/systemd/logind.conf 
sudo systemctl restart systemd-logind

==> cmsform-gcp-8.0.000.11.tar.gz: cmsform/scripts/es.sh <==
#!/bin/bash
CS1_IP=$1
TIMETAG=$2
HOSTVAR=$3
HOSTDOMAIN=$4

#INSTANCENAME=$(curl -H "Metadata-Flavor: Google" http://metadata.google.internal/computeMetadata/v1/instance/name)
#INSTANCEZONE=$(curl -H "Metadata-Flavor: Google" http://metadata.google.internal/computeMetadata/v1/instance/zone)

## mkdir -p /opt/vmTools
## mkdir -p /opt/vmTools
##  # setup for using nfs client
## systemctl enable rpcbind.service
## systemctl start rpcbind
## "echo 'PEERDNS=no' | sudo tee -a /etc/sysconfig/network-scripts/ifcfg-eth0"
## # set the hostname
## hostname $HOSTNAME
## sed -i "/HOSTNAME=localhost.localdomain/c\\HOSTNAME=$HOSTNAME" /etc/sysconfig/network
## #turn off SELinux
## setenforce 0
## sed -i --follow-symlinks 's/^SELINUX=.*/SELINUX=disabled/g' /etc/sysconfig/selinux
##  #remove packages which will conflict with CMS packages
## sudo yum erase -y python-setuptools
## #iptables blocks access to httpd
## sudo systemctl stop firewalld

sudo chmod +x /opt/vmTools/*.sh
#sudo bash /opt/vmTools/mountVMdisk.sh /var/log "0% 25%" /opt "26% 100%"
#sudo bash /opt/vmTools/setHostname.sh ${var.cms_hostname_es}${count.index + 1}
#sudo bash /opt/vmTools/setHostname.sh ${HOSTVAR}${TIMETAG}
sudo hostnamectl set-hostname ${HOSTVAR}${TIMETAG}
echo 'PEERDNS=no' | sudo tee -a /etc/sysconfig/network-scripts/ifcfg-eth0
sudo setenforce 0
sudo sed -i --follow-symlinks 's/^SELINUX=.*/SELINUX=disabled/g' /etc/sysconfig/selinux
sudo yum erase -y python-setuptools
sudo systemctl stop firewalld
sudo bash /opt/vmTools/waitAndPullNodeInstall.sh http://$CS1_IP:8008/cms-node-config.tgz
cd /opt/cms/staging

T_RANDOM=$(shuf -i 0-5 -n 1)
T1=$((${T_RANDOM} * 20))
T2=$((${TIMETAG} *20 % 100))
SLEEPTIME=$(($T1 + $T2))
echo "Sleeping with $SLEEPTIME" | sudo tee -a /home/test/gcpstartup.test.log;
#echo "Sleeping with $SLEEPTIME" | sudo tee -a /var/log/cms/installer/installcmsnode.log;

sleep $SLEEPTIME
# Do not specify the cname, the scripts cmsnsupdate.sh will set the cname automatically, limited within 10
sudo bash installcmsnode.sh es -t 600 |& sudo tee -a /var/log/cms/installer/installcmsnode.log; test $${PIPESTATUS[0]} -eq 0
## Reset the hostname to align with the cname
COUNT=$(cat /etc/facter/facts.d/node.yaml | grep 'cname: es' | grep -o [0-9]*)
sudo hostnamectl set-hostname $HOSTVAR$COUNT
sudo /bin/bash /etc/puppetlabs/code/modules/named/files/cmsnsupdate.sh
### Also need to update the hostname into GCP internal metadata server
#SCTOKEN=$(curl -H "Metadata-Flavor: Google" "http://metadata.google.internal/computeMetadata/v1/instance/service-accounts/default/token"|jq .access_token)
#curl https://compute.googleapis.com/compute/v1/$INSTANCEZONE/instances/$INSTANCENAME -H "Authorization":"Bearer $SCTOKEN" |jq .metadata > /home/instance_meta.json
#sed -i '/"items":/a{ "key": "hostname", "value": "'${HOSTVAR}${COUNT}'.'${HOSTDOMAIN}'" },' /home/instance_meta.json
#curl -X POST https://compute.googleapis.com/compute/v1/$INSTANCEZONE/instances/$INSTANCENAME/setMetadata -H "Authorization":"Bearer $SCTOKEN" -H "Content-Type: application/json" -d @/home/instance_meta.json
#
### Create label 
#LABELFP=$(curl https://compute.googleapis.com/compute/v1/$INSTANCEZONE/instances/$INSTANCENAME -H "Authorization":"Bearer $SCTOKEN" |jq .labelFingerprint)
#curl -X POST https://compute.googleapis.com/compute/v1/$INSTANCEZONE/instances/$INSTANCENAME/setLabels -H "Authorization":"Bearer $SCTOKEN" -H "Content-Type: application/json" -d '{ "labels": { "node": "'${HOSTVAR}${COUNT}'" }, "labelFingerprint": '${LABELFP}' }'
sudo bash /opt/vmTools/scripts/update_instance_metadata.sh $HOSTVAR$COUNT $HOSTDOMAIN

# Config the systemd-logind to make sure the customized shutdown scripts could be run before VM deleted
sudo sed -i '/PATH=/a sudo sh \/opt\/vmTools\/scripts\/deregister_node.sh' /etc/acpi/actions/power.sh
sudo sed -i '/HandlePowerKey/c HandlePowerKey=ignore' /etc/systemd/logind.conf 
sudo systemctl restart systemd-logind
